diff src/SDL_error.c @ 1361:19418e4422cb

New configure-based build system. Still work in progress, but much improved
author Sam Lantinga <slouken@libsdl.org>
date Thu, 16 Feb 2006 10:11:48 +0000
parents c71e05b4dc2e
children c0a74f199ecf
line wrap: on
line diff
--- a/src/SDL_error.c	Fri Feb 10 07:29:08 2006 +0000
+++ b/src/SDL_error.c	Thu Feb 16 10:11:48 2006 +0000
@@ -24,16 +24,15 @@
 
 #include "SDL_error.h"
 #include "SDL_error_c.h"
-#ifndef DISABLE_THREADS
-#include "SDL_thread_c.h"
-#endif
 
 #ifdef DISABLE_THREADS
 /* The default (non-thread-safe) global error variable */
 static SDL_error SDL_global_error;
-
 #define SDL_GetErrBuf()	(&SDL_global_error)
-#endif /* DISABLE_THREADS */
+#else
+extern SDL_error *SDL_GetErrBuf(void);
+#endif /* SDL_THREADS_DISABLED */
 
 #define SDL_ERRBUFIZE	1024
@@ -24,16 +24,15 @@
 
-#ifdef DISABLE_THREADS
-/* The default (non-thread-safe) global error variable */
+/* Routine to get the thread-specific error variable */
+#if SDL_THREADS_DISABLED
+/* The  SDL_arraysize(The ),default (non-thread-safe) global error variable */
 static SDL_error SDL_global_error;